@@ -146,6 +146,24 @@ pub fn main() -> Result<()> {
     }
 
     match cmd {
+        Subcommands::IsClean | Subcommands::IsChanged => {
+            let mode = if matches!(cmd, Subcommands::IsClean) {
+                core::repository::dirty::Mode::IsClean
+            } else {
+                core::repository::dirty::Mode::IsDirty
+            };
+            prepare_and_run(
+                "clean",
+                trace,
+                verbose,
+                progress,
+                progress_keep_open,
+                None,
+                move |_progress, out, _err| {
+                    core::repository::dirty::check(repository(Mode::Lenient)?, mode, out, format)
+                },
+            )
+        }
         #[cfg(feature = "gitoxide-core-tools-clean")]
         Subcommands::Clean(crate::plumbing::options::clean::Command {
             debug,
@@ -188,10 +206,13 @@ pub fn main() -> Result<()> {
             },
         ),
         Subcommands::Status(crate::plumbing::options::status::Platform {
+            ignored,
+            format: status_format,
             statistics,
             submodules,
             no_write,
             pathspec,
+            index_worktree_renames,
         }) => prepare_and_run(
             "status",
             trace,
@@ -208,31 +229,56 @@ pub fn main() -> Result<()> {
                     err,
                     progress,
                     core::repository::status::Options {
-                        format,
+                        format: match status_format.unwrap_or_default() {
+                            crate::plumbing::options::status::Format::Simplified => {
+                                core::repository::status::Format::Simplified
+                            }
+                            crate::plumbing::options::status::Format::PorcelainV2 => {
+                                core::repository::status::Format::PorcelainV2
+                            }
+                        },
+                        ignored: ignored.map(|ignored| match ignored.unwrap_or_default() {
+                            crate::plumbing::options::status::Ignored::Matching => {
+                                core::repository::status::Ignored::Matching
+                            }
+                            crate::plumbing::options::status::Ignored::Collapsed => {
+                                core::repository::status::Ignored::Collapsed
+                            }
+                        }),
+                        output_format: format,
                         statistics,
                         thread_limit: thread_limit.or(cfg!(target_os = "macos").then_some(3)), // TODO: make this a configurable when in `gix`, this seems to be optimal on MacOS, linux scales though! MacOS also scales if reading a lot of files for refresh index
                         allow_write: !no_write,
-                        submodules: match submodules {
+                        index_worktree_renames: index_worktree_renames.map(|percentage| percentage.unwrap_or(0.5)),
+                        submodules: submodules.map(|submodules| match submodules {
                             Submodules::All => core::repository::status::Submodules::All,
                             Submodules::RefChange => core::repository::status::Submodules::RefChange,
                             Submodules::Modifications => core::repository::status::Submodules::Modifications,
-                        },
+                            Submodules::None => core::repository::status::Submodules::None,
+                        }),
                     },
                 )
             },
         ),
         Subcommands::Submodule(platform) => match platform
             .cmds
-            .unwrap_or(crate::plumbing::options::submodule::Subcommands::List)
+            .unwrap_or(crate::plumbing::options::submodule::Subcommands::List { dirty_suffix: None })
         {
-            crate::plumbing::options::submodule::Subcommands::List => prepare_and_run(
+            crate::plumbing::options::submodule::Subcommands::List { dirty_suffix } => prepare_and_run(
                 "submodule-list",
                 trace,
                 verbose,
                 progress,
                 progress_keep_open,
                 None,
-                move |_progress, out, _err| core::repository::submodule::list(repository(Mode::Lenient)?, out, format),
+                move |_progress, out, _err| {
+                    core::repository::submodule::list(
+                        repository(Mode::Lenient)?,
+                        out,
+                        format,
+                        dirty_suffix.map(|suffix| suffix.unwrap_or_else(|| "dirty".to_string())),
+                    )
+                },
             ),
         },
         #[cfg(feature = "gitoxide-core-tools-archive")]
@@ -1036,6 +1082,7 @@ pub fn main() -> Result<()> {
                 statistics,
                 max_candidates,
                 rev_spec,
+                dirty_suffix,
             } => prepare_and_run(
                 "commit-describe",
                 trace,
@@ -1057,6 +1104,7 @@ pub fn main() -> Result<()> {
                             statistics,
                             max_candidates,
                             always,
+                            dirty_suffix: dirty_suffix.map(|suffix| suffix.unwrap_or_else(|| "dirty".to_string())),
                         },
                     )
                 },
